package Bundle::Locale::CLDR::Easternasia;

use version;

our $VERSION = version->declare('v0.46.0');

=head1 NAME

Bundle::Locale::CLDR::Easternasia

=head1 CONTENTS

Locale::CLDR::Locales::Bo 0.46.0

Locale::CLDR::Locales::Ii 0.46.0

Locale::CLDR::Locales::Ja 0.46.0

Locale::CLDR::Locales::Ko 0.46.0

Locale::CLDR::Locales::Mn 0.46.0

Locale::CLDR::Locales::Pt 0.46.0

Locale::CLDR::Locales::Ug 0.46.0

Locale::CLDR::Locales::Za 0.46.0

Locale::CLDR::Locales::Zh 0.46.0

Locale::CLDR::Locales::Trv 0.46.0

Locale::CLDR::Locales::Yue 0.46.0

Locale::CLDR::Locales::Bo::Tibt 0.46.0

Locale::CLDR::Locales::Ii::Yiii 0.46.0

Locale::CLDR::Locales::Ja::Jpan 0.46.0

Locale::CLDR::Locales::Kk::Arab 0.46.0

Locale::CLDR::Locales::Ko::Kore 0.46.0

Locale::CLDR::Locales::Mn::Cyrl 0.46.0

Locale::CLDR::Locales::Mn::Mong 0.46.0

Locale::CLDR::Locales::Pt::Latn 0.46.0

Locale::CLDR::Locales::Ug::Arab 0.46.0

Locale::CLDR::Locales::Za::Latn 0.46.0

Locale::CLDR::Locales::Zh::Hans 0.46.0

Locale::CLDR::Locales::Zh::Hant 0.46.0

Locale::CLDR::Locales::Zh::Latn 0.46.0

Locale::CLDR::Locales::Trv::Latn 0.46.0

Locale::CLDR::Locales::Yue::Hans 0.46.0

Locale::CLDR::Locales::Yue::Hant 0.46.0

Locale::CLDR::Locales::Bo::Tibt::Cn 0.46.0

Locale::CLDR::Locales::En::Latn::Hk 0.46.0

Locale::CLDR::Locales::En::Latn::Mo 0.46.0

Locale::CLDR::Locales::Ii::Yiii::Cn 0.46.0

Locale::CLDR::Locales::Ja::Jpan::Jp 0.46.0

Locale::CLDR::Locales::Kk::Arab::Cn 0.46.0

Locale::CLDR::Locales::Ko::Kore::Cn 0.46.0

Locale::CLDR::Locales::Ko::Kore::Kp 0.46.0

Locale::CLDR::Locales::Ko::Kore::Kr 0.46.0

Locale::CLDR::Locales::Mn::Cyrl::Mn 0.46.0

Locale::CLDR::Locales::Mn::Mong::Cn 0.46.0

Locale::CLDR::Locales::Mn::Mong::Mn 0.46.0

Locale::CLDR::Locales::Pt::Latn::Mo 0.46.0

Locale::CLDR::Locales::Pt::Latn::Pt 0.46.0

Locale::CLDR::Locales::Ug::Arab::Cn 0.46.0

Locale::CLDR::Locales::Za::Latn::Cn 0.46.0

Locale::CLDR::Locales::Zh::Hans::Cn 0.46.0

Locale::CLDR::Locales::Zh::Hans::Hk 0.46.0

Locale::CLDR::Locales::Zh::Hans::Mo 0.46.0

Locale::CLDR::Locales::Zh::Hant::Hk 0.46.0

Locale::CLDR::Locales::Zh::Hant::Mo 0.46.0

Locale::CLDR::Locales::Zh::Hant::Tw 0.46.0

Locale::CLDR::Locales::Zh::Latn::Cn 0.46.0

Locale::CLDR::Locales::En::Latn::001 0.46.0

Locale::CLDR::Locales::Trv::Latn::Tw 0.46.0

Locale::CLDR::Locales::Yue::Hans::Cn 0.46.0

Locale::CLDR::Locales::Yue::Hant::Cn 0.46.0

Locale::CLDR::Locales::Yue::Hant::Hk 0.46.0


=cut

1;

